@@ -4,7 +4,7 @@ from PIL import Image
 from . import yfile
 
 
-def transponse_image(img_dir: str, terget_dir: str = 'Converted') -> None:
+def transponse(img_dir: str, terget_dir: str = 'Converted') -> None:
     """
     Mirror Images
     :param img_dir: path to images dir
@@ -23,23 +23,18 @@ def transponse_image(img_dir: str, terget_dir: str = 'Converted') -> None:
             target_image.transpose(Image.FLIP_LEFT_RIGHT).save(target_path)
 
 
-def mirror_img(img_path: str) -> Image.Image:
+def mirror(img_path: str) -> Image.Image:
     """
     Mirror the Image
     :param img_path: path to input image file
     :return: PIL.Image obj
     """
-
-    #
-    # To-Do Fix the quality is too low
-    #
-
     img = Image.open(img_path)
 
     return img.transpose(Image.FLIP_LEFT_RIGHT)
 
 
-def comp_img(img_path: str, target_size: int = 1000, step: int = 1, quality: int = 100) -> Image.Image:
+def comp(img_path: str, target_size: int = 1000, step: int = 1, quality: int = 100) -> Image.Image:
     """
     Compress the image filezie to the target filesize without changing the image size
     :param img_path: the path of image file
@@ -77,7 +72,7 @@ def comp_img(img_path: str, target_size: int = 1000, step: int = 1, quality: int
     return img
 
 
-def watermask_image(img_path: str, mark_path: str) -> Image.Image:
+def watermask(img_path: str, mark_path: str) -> Image.Image:
     """
     Add Watermark into Image
     :param img_path: path of image file
